# Changelog

## Version 0.3.0 (development)

- fix parsing of the response when setting a target temperature

## Version 0.2.2 (development)

- various communication fixes
- allow disabling humidity control
- change package name

## Version 0.2.1 (development)

- feat: Initial climate_chamber
